pub struct DomainCreateFlags { /* private fields */ }Implementations
Sourceimpl DomainCreateFlags
impl DomainCreateFlags
Sourcepub fn empty() -> DomainCreateFlags
pub fn empty() -> DomainCreateFlags
Returns an empty set of flags.
Sourcepub fn all() -> DomainCreateFlags
pub fn all() -> DomainCreateFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<DomainCreateFlags>
pub fn from_bits(bits: u32) -> Option<DomainCreateFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> DomainCreateFlags
pub fn from_bits_truncate(bits: u32) -> DomainCreateFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: DomainCreateFlags) -> bool
pub fn intersects(&self, other: DomainCreateFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: DomainCreateFlags) -> bool
pub fn contains(&self, other: DomainCreateFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: DomainCreateFlags)
pub fn insert(&mut self, other: DomainCreateFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: DomainCreateFlags)
pub fn remove(&mut self, other: DomainCreateFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: DomainCreateFlags)
pub fn toggle(&mut self, other: DomainCreateFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: DomainCreateFlags, value: bool)
pub fn set(&mut self, other: DomainCreateFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.