pub struct DomainDestroyFlags { /* private fields */ }Implementations
Sourceimpl DomainDestroyFlags
impl DomainDestroyFlags
Sourcepub fn empty() -> DomainDestroyFlags
pub fn empty() -> DomainDestroyFlags
Returns an empty set of flags.
Sourcepub fn all() -> DomainDestroyFlags
pub fn all() -> DomainDestroyFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<DomainDestroyFlags>
pub fn from_bits(bits: u32) -> Option<DomainDestroyFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> DomainDestroyFlags
pub fn from_bits_truncate(bits: u32) -> DomainDestroyFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: DomainDestroyFlags) -> bool
pub fn intersects(&self, other: DomainDestroyFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: DomainDestroyFlags) -> bool
pub fn contains(&self, other: DomainDestroyFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: DomainDestroyFlags)
pub fn insert(&mut self, other: DomainDestroyFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: DomainDestroyFlags)
pub fn remove(&mut self, other: DomainDestroyFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: DomainDestroyFlags)
pub fn toggle(&mut self, other: DomainDestroyFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: DomainDestroyFlags, value: bool)
pub fn set(&mut self, other: DomainDestroyFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.