pub struct DomainMigrateFlags { /* private fields */ }Implementations
Sourceimpl DomainMigrateFlags
impl DomainMigrateFlags
Sourcepub fn empty() -> DomainMigrateFlags
pub fn empty() -> DomainMigrateFlags
Returns an empty set of flags.
Sourcepub fn all() -> DomainMigrateFlags
pub fn all() -> DomainMigrateFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<DomainMigrateFlags>
pub fn from_bits(bits: u32) -> Option<DomainMigrateFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> DomainMigrateFlags
pub fn from_bits_truncate(bits: u32) -> DomainMigrateFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: DomainMigrateFlags) -> bool
pub fn intersects(&self, other: DomainMigrateFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: DomainMigrateFlags) -> bool
pub fn contains(&self, other: DomainMigrateFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: DomainMigrateFlags)
pub fn insert(&mut self, other: DomainMigrateFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: DomainMigrateFlags)
pub fn remove(&mut self, other: DomainMigrateFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: DomainMigrateFlags)
pub fn toggle(&mut self, other: DomainMigrateFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: DomainMigrateFlags, value: bool)
pub fn set(&mut self, other: DomainMigrateFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.