pub struct MemoryModificationImpact { /* private fields */ }Implementations
Sourceimpl MemoryModificationImpact
impl MemoryModificationImpact
Sourcepub fn empty() -> MemoryModificationImpact
pub fn empty() -> MemoryModificationImpact
Returns an empty set of flags.
Sourcepub fn all() -> MemoryModificationImpact
pub fn all() -> MemoryModificationImpact
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<MemoryModificationImpact>
pub fn from_bits(bits: u32) -> Option<MemoryModificationImpact>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> MemoryModificationImpact
pub fn from_bits_truncate(bits: u32) -> MemoryModificationImpact
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: MemoryModificationImpact) -> bool
pub fn intersects(&self, other: MemoryModificationImpact) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: MemoryModificationImpact) -> bool
pub fn contains(&self, other: MemoryModificationImpact) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: MemoryModificationImpact)
pub fn insert(&mut self, other: MemoryModificationImpact)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: MemoryModificationImpact)
pub fn remove(&mut self, other: MemoryModificationImpact)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: MemoryModificationImpact)
pub fn toggle(&mut self, other: MemoryModificationImpact)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: MemoryModificationImpact, value: bool)
pub fn set(&mut self, other: MemoryModificationImpact, value: bool)
Inserts or removes the specified flags depending on the passed value.