pub struct VcpuModificationImpact { /* private fields */ }Implementations
Sourceimpl VcpuModificationImpact
impl VcpuModificationImpact
Sourcepub fn empty() -> VcpuModificationImpact
pub fn empty() -> VcpuModificationImpact
Returns an empty set of flags.
Sourcepub fn all() -> VcpuModificationImpact
pub fn all() -> VcpuModificationImpact
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<VcpuModificationImpact>
pub fn from_bits(bits: u32) -> Option<VcpuModificationImpact>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> VcpuModificationImpact
pub fn from_bits_truncate(bits: u32) -> VcpuModificationImpact
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: VcpuModificationImpact) -> bool
pub fn intersects(&self, other: VcpuModificationImpact) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: VcpuModificationImpact) -> bool
pub fn contains(&self, other: VcpuModificationImpact) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: VcpuModificationImpact)
pub fn insert(&mut self, other: VcpuModificationImpact)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: VcpuModificationImpact)
pub fn remove(&mut self, other: VcpuModificationImpact)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: VcpuModificationImpact)
pub fn toggle(&mut self, other: VcpuModificationImpact)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: VcpuModificationImpact, value: bool)
pub fn set(&mut self, other: VcpuModificationImpact, value: bool)
Inserts or removes the specified flags depending on the passed value.