pub struct DomainXmlFlags { /* private fields */ }Implementations
Sourceimpl DomainXmlFlags
impl DomainXmlFlags
Sourcepub fn empty() -> DomainXmlFlags
pub fn empty() -> DomainXmlFlags
Returns an empty set of flags.
Sourcepub fn all() -> DomainXmlFlags
pub fn all() -> DomainXmlFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<DomainXmlFlags>
pub fn from_bits(bits: u32) -> Option<DomainXmlFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> DomainXmlFlags
pub fn from_bits_truncate(bits: u32) -> DomainXmlFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: DomainXmlFlags) -> bool
pub fn intersects(&self, other: DomainXmlFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: DomainXmlFlags) -> bool
pub fn contains(&self, other: DomainXmlFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: DomainXmlFlags)
pub fn insert(&mut self, other: DomainXmlFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: DomainXmlFlags)
pub fn remove(&mut self, other: DomainXmlFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: DomainXmlFlags)
pub fn toggle(&mut self, other: DomainXmlFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: DomainXmlFlags, value: bool)
pub fn set(&mut self, other: DomainXmlFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.