pub struct ListAllDomainsFlags { /* private fields */ }Implementations
Sourceimpl ListAllDomainsFlags
impl ListAllDomainsFlags
Sourcepub fn empty() -> ListAllDomainsFlags
pub fn empty() -> ListAllDomainsFlags
Returns an empty set of flags.
Sourcepub fn all() -> ListAllDomainsFlags
pub fn all() -> ListAllDomainsFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<ListAllDomainsFlags>
pub fn from_bits(bits: u32) -> Option<ListAllDomainsFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> ListAllDomainsFlags
pub fn from_bits_truncate(bits: u32) -> ListAllDomainsFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: ListAllDomainsFlags) -> bool
pub fn intersects(&self, other: ListAllDomainsFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: ListAllDomainsFlags) -> bool
pub fn contains(&self, other: ListAllDomainsFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: ListAllDomainsFlags)
pub fn insert(&mut self, other: ListAllDomainsFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: ListAllDomainsFlags)
pub fn remove(&mut self, other: ListAllDomainsFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: ListAllDomainsFlags)
pub fn toggle(&mut self, other: ListAllDomainsFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: ListAllDomainsFlags, value: bool)
pub fn set(&mut self, other: ListAllDomainsFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.