pub struct StorageVolCreateXmlFlags { /* private fields */ }Implementations
Sourceimpl StorageVolCreateXmlFlags
impl StorageVolCreateXmlFlags
Sourcepub fn empty() -> StorageVolCreateXmlFlags
pub fn empty() -> StorageVolCreateXmlFlags
Returns an empty set of flags.
Sourcepub fn all() -> StorageVolCreateXmlFlags
pub fn all() -> StorageVolCreateXmlFlags
Returns the set containing all flags.
Sourcepub fn from_bits(bits: u32) -> Option<StorageVolCreateXmlFlags>
pub fn from_bits(bits: u32) -> Option<StorageVolCreateXmlFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub fn from_bits_truncate(bits: u32) -> StorageVolCreateXmlFlags
pub fn from_bits_truncate(bits: u32) -> StorageVolCreateXmlFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub fn intersects(&self, other: StorageVolCreateXmlFlags) -> bool
pub fn intersects(&self, other: StorageVolCreateXmlFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub fn contains(&self, other: StorageVolCreateXmlFlags) -> bool
pub fn contains(&self, other: StorageVolCreateXmlFlags) -> bool
Returns true all of the flags in other are contained within self.
Sourcepub fn insert(&mut self, other: StorageVolCreateXmlFlags)
pub fn insert(&mut self, other: StorageVolCreateXmlFlags)
Inserts the specified flags in-place.
Sourcepub fn remove(&mut self, other: StorageVolCreateXmlFlags)
pub fn remove(&mut self, other: StorageVolCreateXmlFlags)
Removes the specified flags in-place.
Sourcepub fn toggle(&mut self, other: StorageVolCreateXmlFlags)
pub fn toggle(&mut self, other: StorageVolCreateXmlFlags)
Toggles the specified flags in-place.
Sourcepub fn set(&mut self, other: StorageVolCreateXmlFlags, value: bool)
pub fn set(&mut self, other: StorageVolCreateXmlFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.