Struct libvirt_rpc::request::flags::ListAllDomainsFlags
[−]
pub struct ListAllDomainsFlags { /* fields omitted */ }Methods
impl ListAllDomainsFlags
fn empty() -> ListAllDomainsFlags
Returns an empty set of flags.
fn all() -> ListAllDomainsFlags
Returns the set containing all flags.
fn bits(&self) -> u32
Returns the raw value of the flags currently stored.
fn from_bits(bits: u32) -> Option<ListAllDomainsFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
fn from_bits_truncate(bits: u32) -> ListAllDomainsFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
fn is_all(&self) -> bool
Returns true if all flags are currently set.
fn intersects(&self, other: ListAllDomainsFlags) -> bool
Returns true if there are flags common to both self and other.
fn contains(&self, other: ListAllDomainsFlags) -> bool
Returns true all of the flags in other are contained within self.
fn insert(&mut self, other: ListAllDomainsFlags)
Inserts the specified flags in-place.
fn remove(&mut self, other: ListAllDomainsFlags)
Removes the specified flags in-place.
fn toggle(&mut self, other: ListAllDomainsFlags)
Toggles the specified flags in-place.
fn set(&mut self, other: ListAllDomainsFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.